Learn R Programming

convertid (version 0.2.0)

.get.httr_config: Unexported functions Get httr configuration, i.e., current CURL options for data fetching functions.

Description

.get.httr_config() retrieves the current CURL options and in particular tests and gets the options used with "^https://.*ensembl.org" URLs. The code was partly copied from listMarts().

Usage

.get.httr_config(
  httr_config,
  host = "https://www.ensembl.org",
  use.cache = TRUE
)

Value

A R object of class request listing current CURL options.

Arguments

httr_config

(list). A R object of class request listing current CURL options. Missing (and meant to be created) by default.

host

(character) Host URL.

use.cache

(logical) Should biomaRt functions use the cache? Defaults to TRUE.

See Also

Examples

Run this code
if (FALSE) .get.httr_config()

Run the code above in your browser using DataLab